@@ -19,12 +19,15 @@ ExerciseWindow::ExerciseWindow(QWidget *parent) :
 
     vLayout = new QVBoxLayout;
 
+    QFont font;
+    font.setPointSize(32);
+
     label = new QLabel("");
     label->setAlignment(Qt::AlignCenter);
+    label->setFont(font);
+
 
     btnShake = new QPushButton("Done");
-
-
     connect(btnShake,SIGNAL(clicked()),this,SLOT(shaked()));
 
     vLayout->addWidget(label);
@@ -155,6 +158,12 @@ void ExerciseWindow::sendDestroyDialog()
 
 void ExerciseWindow::openED()
 {
+    //QList <QString > tmp, history;
+
+    //for(int i = 0; i < exercises.count(); i++)
+        //history = xml->getHistoryByDate(exercises.at(i));
+
+    //tmp.append(history.at(0) + " (" + history.at(2) + "-" + history.at(3) + ")")
     if(exercises.count() > 1)
     {
         ed = new ExerciseDialog(this);
